\name{MCA}
\alias{MCA}
\title{
Maximum Covariance Analysis
}
\description{
Computes a Maximum Covariance Analysis (MCA) between vary and varx. 
Returns a vector of squared covariance fraction (SCFs) explained by 
each pair of covariability modes, a vector of correlation coefficient 
(RUVs) between expansion coefficients (ECs) that measures their linear 
relationship, and a set of regression (MCAs) and correlation (CORRs) 
maps associated with the covariability modes. Note that both, MCAs and 
CORRs, are 'homogeneous' patterns obtained as regression/correlation
between each field (predictor, predictand) and its expansion coefficient.
The threshold for the correlation coefficient, based on a two-tailed 
Student's t-test, is also produced.
}
\usage{
MCA(vary, varx, siglev = 0.98)
}
\arguments{
  \item{vary}{
Array containing the anomalies field for the predictor.
  }
  \item{varx}{
Array containing the anomalies field for the predictand.
  }
  \item{siglev}{
Value of the confidence level for the correlation map. It is based on a 
two-tailed Student's t-test. Default is \code{siglev = 0.98} (98% confidence 
level; 2% significance level).
  }
}
\value{
  \item{$SCFs}{
Vector of squared covariance fractions (nm).
  }
  \item{$RUVs}{
Vector of correlations between expansion coefficients (nm).
  }
  \item{$ECs_U}{
Array of expansion coefficients of predictor field (nt, nm).
  }
  \item{$MCAs_U}{
Array of covariability patterns of predictor field (c(dim), nm).
  }
  \item{$CORRs_U}{
Array of corr. maps associated with predictor field (c(dim), nm).
  }
  \item{$ECs_V}{
Array of expansion coefficients of predictand field (nt, nm).
  }
  \item{$MCAs_V}{
Array of covariability patterns of predictand field (c(dim), nm).
  }
  \item{$CORRs_V}{
Array of corr. maps associated with predictand field (c(dim), nm).
  }
  \item{$Rtest}{
Value of the statitically significant corr. coefficient at \code{siglev}.
  }
}
\examples{
}
\author{
History:\cr
0.1  -  2010-09  (J.-G. Serrano, \email{javier.garcia at bsc.es})  -  Original code\cr
1.0  -  2016-04  (N. Manubens, \email{nicolau.manubens at bsc.es})  -  Formatting to R CRAN
}
\keyword{datagen}
